@@ -10,34 +10,10 @@ from django.utils.crypto import constant_time_compare
 from django.utils.encoding import force_unicode
 
 from requests.api import request
-from requests.auth import OAuth1
+from requests_oauthlib import OAuth1
 from requests.exceptions import RequestException
 
-try:
-    from django.utils.crypto import get_random_string
-except ImportError: # pragma: no cover
-    # Backport implementation from Django 1.4
-    import hashlib
-    import random
-    import string
-    import time
-    from django.conf import settings
-    try:
-        random = random.SystemRandom()
-        using_sysrandom = True
-    except NotImplementedError:
-        import warnings
-        warnings.warn('A secure pseudo-random number generator is not available '
-                      'on your system. Falling back to Mersenne Twister.')
-        using_sysrandom = False
-
-    def get_random_string(length=12, allowed_chars=string.ascii_letters + string.digits):
-        "Returns a securely generated random string."
-        if not using_sysrandom:
-            # Re-seed random
-            bytes = b"{0}{1}{2}".format(random.getstate(), time.time(), settings.SECRET_KEY)
-            random.seed(hashlib.sha256(bytes).digest())
-        return ''.join([random.choice(allowed_chars) for i in range(length)])
+from .compat import get_random_string
 
 
 logger = logging.getLogger('allaccess.clients')
@@ -62,7 +38,13 @@ class BaseOAuthClient(object):
             logger.error('Unable to fetch user profile: {0}'.format(e))
             return None
         else:
-            return response.json if response.json is not None else response.text
+            result = response.text
+            # Handle requests 1.0 and pre-1.0
+            if callable(response.json):
+                result = response.json() or result
+            elif response.json is not None:
+                result = response.json
+            return result
 
     def get_redirect_args(self, request, callback):
         "Get request parameters for redirect url."
